==> alfresco-repository-23.3.21.3-sources.jar: org/alfresco/repo/security/authentication/AuthenticatorDeletedEvent.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.security.authentication;

import org.springframework.context.ApplicationEvent;

/**
 * Event emmitted when an Authenticator is deleted, the source is the zoneId deleted.
 *
 * @author mrogers
 */
public class AuthenticatorDeletedEvent extends ApplicationEvent
{
	/**
	 * 
	 */
	private static final long serialVersionUID = 3641164223727881175L;

	/**
	 * 
	 * @param source a String with the zoneid
	 */
	public AuthenticatorDeletedEvent(Object source) 
	{
		super(source);
	}

}

==> alfresco-repository-26.1.0.42-sources.jar: org/alfresco/repo/security/authentication/AuthenticatorDeletedEvent.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.security.authentication;

import org.springframework.context.ApplicationEvent;

/**
 * Event emmitted when an Authenticator is deleted, the source is the zoneId deleted.
 *
 * @author mrogers
 */
public class AuthenticatorDeletedEvent extends ApplicationEvent
{
    /**
     * 
     */
    private static final long serialVersionUID = 3641164223727881175L;

    /**
     * 
     * @param source
     *            a String with the zoneid
     */
    public AuthenticatorDeletedEvent(Object source)
    {
        super(source);
    }

}
